@@ -363,13 +363,13 @@ def silver_to_gold(input_table_name, data_pack_name, dataset_name, input_db_name
         apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
 
 
-def gold_to_kafka(input_table_name, data_pack_name, dataset_name, topic_name, input_db_name=GOLD_DB_NAME, spark=None, write_options: dict = None, kafka_security_protocol='SSL',
+def gold_to_kafka(input_table_name, topic_name, input_db_name=GOLD_DB_NAME, spark=None, write_options: dict = None, kafka_security_protocol='SSL',
                   kafka_bootstrap_servers=DEFAULT_BOOTSTRAP_SERVERS, processing_function=None, processing_function_args=None, processing_function_kwargs=None, reset_checkpoint=False):
     topics = [topic_name]
     create_topics_if_not_exists(topics=topics, bootstrap_servers=kafka_bootstrap_servers)
-    checkpoint_location = f's3://{GOLD_BUCKET}/_databricks_autoloader_checkpoints/kafka/{data_pack_name}/{dataset_name}/{input_table_name}'
+    checkpoint_location = f's3://{GOLD_BUCKET}/_databricks_autoloader_checkpoints/kafka/{input_db_name}/{input_table_name}'
     if spark is None:
-        spark = get_spark_session(app_name=dataset_name)
+        spark = get_spark_session(app_name=input_table_name)
     if reset_checkpoint:
         __delete_checkpoint_location(bucket_name=GOLD_BUCKET, checkpoint_location=checkpoint_location)
     if write_options is None:
